@@ -22,8 +22,10 @@ class RemoteCall:
     def func_call(self, params):
         if type(params) is tuple:
             protocol['args'] = params
+            protocol['kwargs'] = {}
         else:
             protocol['kwargs'] = params
+            protocol['args'] = ()
         service_path = self.service_path.split('/')
         protocol['service_name'] = service_path[:-1]
         protocol['func'] = service_path[-1]
